package com.ruixuan.isc.controller;

import com.ruixuan.common.core.controller.BaseController;
import com.ruixuan.common.utils.DateUtils;
import com.ruixuan.isc.service.IKwaixiaodianItemGetService;
import com.ruixuan.isc.service.IKwaixiaodianOrderCursorListService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * kwaixiaodian商品详情Controller
 *
 * @date 2024-10-28
 */
@Api(tags = "Kwaixiaodian")
@RestController
@RequestMapping("/kwaixiaodian/item")
public class KwaixiaodianItemGetController extends BaseController {
    @Autowired
    private IKwaixiaodianItemGetService kwaixiaodianItemGetService;

    @Autowired
    private IKwaixiaodianOrderCursorListService orderCursorListService;

    /**
     * 获取商品详情（open.item.get)
     * https://open.kwaixiaodian.com/zone/new/docs/api?name=open.item.get&version=1
     */
    @GetMapping("/querykwaiItmInfo")
    @ApiOperation(value = "获kwai商品详情")
    public void querykwaiItmInfo(
            @ApiParam("商品ID") @RequestParam(value = "kwaiItemId", required = false) Long kwaiItemId,
            @ApiParam("店铺ID") @RequestParam(value = "shopId", required = false) String shopId,
            @ApiParam("用户ID") @RequestParam(value = "userId", required = false) String userId,
            @ApiParam("用户") @RequestParam(value = "userName", required = false) String userName) {
        try {
            kwaixiaodianItemGetService.querykwaiItmInfo(kwaiItemId, shopId, userId, userName);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 获取订单列表（open.order.cursor.list)
     * https://open.kwaixiaodian.com/zone/new/docs/api?name=open.order.cursor.list&version=1
     */
    @GetMapping("/querykwaiOrderList")
    @ApiOperation(value = "获kwai订单列表")
    public void querykwaiOrderList(
            @ApiParam("店铺ID") @RequestParam(value = "shopId", required = false) String shopId
            , @ApiParam("1按创建时间查找 2按更新时间查找") @RequestParam(value = "queryType", required = false) Integer queryType
            , @ApiParam("开始日期") @RequestParam(value = "beginDate", required = false) String beginDate
            , @ApiParam("结束日期（间隔不大于7天）") @RequestParam(value = "endDate", required = false) String endDate

    ) {
        try {
            orderCursorListService.querykwaiOrderList(shopId.trim(), queryType, beginDate, endDate, "");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 获取订单列表（open.order.cursor.list)
     * https://open.kwaixiaodian.com/zone/new/docs/api?name=open.order.cursor.list&version=1
     */
    @GetMapping("/querykwaiOrderList2")
    @ApiOperation(value = "获kwai订单列表2")
    public void querykwaiOrderList2(@ApiParam("店铺ID") @RequestParam(value = "shopId", required = false) String shopId) {
        List<String> allDatesOfTwoTimes = DateUtils.getAllDatesOfTwoTimes("2024-10-01", "2024-10-30");
        for (String date : allDatesOfTwoTimes) {
            orderCursorListService.querykwaiOrderList(shopId.trim(), 1, date, date, "");
            logger.info("shopID:{},日期：{} 执行-----ok", shopId, date);
        }
//            JSONObject eventJSon = new JSONObject();
//            eventJSon.put("info", "{\"oid\":2429701614840853,\"sellerId\":3452197807,\"status\":50,\"updateTime\":1730269385968}");
//            eventJSon.put("openId", "f1877fdf0495636114bf572414119bed");
//            orderCursorListService.insertKWaiShopOrder(eventJSon);
    }

}
